close all
clearvars
clc


% This file computes and saves basic parameter values in the MAT file
% called HKK_paramters.mat, which contains 
% (1) par_ERT0
% (2) par_SIR0
% (3) par_HKK0

% Packing parameter values
par.pi_d        = 7*0.005/18;
par.pi_r        = 7/18 - par.pi_d;

par.Pop0        = 1;
par.epsilon     = 0.001;
% par.epsilon     = 0.0001;
par.I0          = par.epsilon;
par.S0          = 1-par.epsilon;

par.A           = 39.83516484;
par.theta       = 0.00127551020408163;
par.phi_tilde   = 0.8;
par.phi_star    = 0.8;
par.phi_r_star  = 1;
par.phi_r_tilde = 1;
par.beta        = 0.96^(1/52);

par.H           = 250;
% par.H           = 108;

% Misperception parameter
par.psi = 1;

% Testing efficiency parameter
par.chi     = 1;
% AB test efficiency parameter
par.chi_AB  = 1;

% Initial steady-state values
par.n_ss    = 28;
par.c_ss    = par.n_ss*par.A;

% Medical preparedness parameters
par.chi_bar = par.chi;
par.kappa   = 0;

% Zero containment rate (beseline)
muc = zeros(par.H,1);
% Zero wage subsidy
muw_s       = zeros(par.H,1);
muw_i_tilde = zeros(par.H,1);
muw_i_star  = zeros(par.H,1);
muw_r       = zeros(par.H,1);

MUs = [muc, muw_s, muw_i_tilde, muw_r, muw_i_tilde];

% --- Calibrating pi_s's ---
for i = 1:3
    if i == 1
        % --- ERT ---
        par.target_1 = 1/6;
        par.target_2 = 1/6;
        par.target_4 = 0;
        par.target_5 = 0;
        par.target_rd = 0.6;
    elseif i == 2
        % --- Standard SIR ---
        par.target_1 = 0;
        par.target_2 = 0;
        par.target_4 = 0;
        par.target_5 = 0;
        par.target_rd = 0.6;
    elseif i == 3
        % --- HKK ---
        par.target_1 = 3/8;
        par.target_2 = 3/8;
        par.target_4 = 0;
        par.target_5 = 0;
        par.target_rd = 0.6;
    end
    
    MyObj = @(x) CalibTarget(x, par);
    % Option for fsolve
    opt = optimoptions(@fsolve, 'Display', 'iter', 'TolFun', 1e-9);
    % Initial guess
    PIs0 = zeros(5,1)+0.001;
    % Solve for pi_s
    [PIs, ~, exitflag] = fsolve(MyObj, PIs0, opt);
    if exitflag ~= 1
        error('Calibration failed.')
    end
    
    PIs = abs(PIs);
    par.pi_s1 = PIs(1)/1000;
    par.pi_s2 = PIs(2)/1000;
    par.pi_s3 = PIs(3);
    par.pi_s4 = PIs(4)/1000;
    par.pi_s5 = PIs(5)/1000;
    
    % Make sure that some pi's are zeros
    if i == 1
        % --- ERT ---
        par_ERT0 = par;
        par_ERT0.pi_s4 = 0;
        par_ERT0.pi_s5 = 0;
    elseif i == 2
        % --- Standard SIR ---
        par_SIR0 = par;
        par_SIR0.pi_s1 = 0;
        par_SIR0.pi_s2 = 0;
        par_SIR0.pi_s4 = 0;
        par_SIR0.pi_s5 = 0;
    elseif i == 3
        % --- Standard SIR ---
        par_HKK0 = par;
        par_HKK0.pi_s4 = 0;
        par_HKK0.pi_s5 = 0;
    end
    
end


save HKK_parameters par_ERT0 par_SIR0 par_HKK0 MUs
% save HKK_parameters_SMALL par_ERT0 par_SIR0 par_HKK0 MUs

