close all
clearvars
clc

CT = PlotColor(5, 'blue');
set(groot,'defaultAxesColorOrder', CT);
set(groot,'defaultLineLineWidth', 2);
set(groot,'defaultAxesTitleFontWeight','normal');

PSIs = [0.4:0.3:1.6];
MUCts = zeros(250,5);

I_ALL = zeros(250,5);
S_ALL = zeros(250,5);
R_ALL = zeros(250,5);
D_ALL = zeros(250,5);
C_ALL = zeros(250,5);
H_ALL = zeros(250,5);

U0_ALL = zeros(5,1);

for i = 1:5
    if i == 1
        load OptMuc_04_20200917.mat
    elseif i == 2
        load OptMuc_07_20200917.mat
    elseif i == 3
        load OptMuc_10_20200917.mat
    elseif i == 4
        load OptMuc_13_20200917.mat
    elseif i == 5
        load OptMuc_16_20200917.mat
    end
    

MUCts(:,i) = muc_t;

% - Internal Objective function
ObjFun = @(x) imperfect_ObjFun_simple(x, MUs, par);

opt_fsolve = optimoptions(@fsolve, 'Display', 'iter');


[N, ~, exitflag] = fsolve(ObjFun, guessN, opt_fsolve);
if exitflag ~= 1
    error('Incomplete Solution.')
end

X = imperfect_DynPath_simple(N, MUs, par);

N = reshape(N, par.H, 3);
X.ns          = N(:,1);
X.ni_tilde    = N(:,2);
X.nr_tilde    = N(:,3);


Hi = X.I.*par.phi_tilde.*X.ni_tilde;
RCr = X.R.*cr_tilde;
Hr = X.R.*X.nr_tilde*par.phi_r_tilde;

U0 = X.S(1)*X.Us_true(1) + X.I(1)*( X.Ui_tilde(1) );
      
C = X.S.*X.cs + X.ICi + RCr;
H = X.S.*X.ns + Hi + Hr;

I_ALL(:,i) = X.I;
S_ALL(:,i) = X.S;
R_ALL(:,i) = X.R;
D_ALL(:,i) = X.D;
C_ALL(:,i) = C;
H_ALL(:,i) = H;


U0_ALL(i) = U0;

end


fig1 = figure;
subplot(2,1,1)
plot(MUCts)
ylabel('\mu_{c,t}')
set(gca, 'XLim', [0, 150])
lh = PutLegend(PSIs, '\psi');
set(lh, 'EdgeColor', 'none')


fig2 = figure;

subplot(2,3,1)
plot([I_ALL]*100);
box off
set(gca, 'XLim', [0, 150])
title('Infected, I')
ylabel('% of Init. Pop.')
xlabel('Weeks')

subplot(2,3,2)
plot([S_ALL]*100);
box off
set(gca, 'XLim', [0, 150])
title('Susceptibles, S')
ylabel('% of Init. Pop.')
xlabel('Weeks')

subplot(2,3,3)
plot([R_ALL]*100);
box off
set(gca, 'XLim', [0, 150])
title('Recovered, R')
ylabel('% of Init. Pop.')
xlabel('Weeks')

subplot(2,3,4)
plot([D_ALL]*100);
box off
set(gca, 'XLim', [0, 150])
title('Deaths, D')
ylabel('% of Init. Pop.')
xlabel('Weeks')

subplot(2,3,5)
plot(([C_ALL] - par.c_ss)./par.c_ss*100);
box off
set(gca, 'XLim', [0, 150])
title('Aggregate Consumption, C')
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
% Zero line
hold on
plot(zeros(par.H,1), ':k', 'LineWidth', 0.5)

subplot(2,3,6)
plot(([H_ALL] - par.n_ss)./par.n_ss*100);
box off
set(gca, 'XLim', [0, 150])
title('Aggregate Hours, H')
ylabel('% Dev. from Init. SS')
xlabel('Weeks')
% Zero line
hold on
plot(zeros(par.H,1), ':k', 'LineWidth', 0.5)

lh = PutLegend(PSIs, '\psi');
set(lh, 'EdgeColor', 'none', 'location', 'SouthEast')

printflag   = 0;    % 1 to save figures as PDF

if printflag == 1
    printPDFcrop(fig1, '../Draft/img/MuCt.pdf')
    printPDFcrop(fig2, '../Draft/img/OptimalContainment_Comp.pdf')
end

set(groot,'defaultAxesColorOrder', 'remove');
set(groot,'defaultLineLineWidth', 'remove')
set(groot,'defaultAxesTitleFontWeight','remove');